@@ -5,7 +5,7 @@ import os
 import re
 import subprocess
 from collections import UserDict
-from typing import TYPE_CHECKING, Dict, List, Literal, Optional, Union
+from typing import Literal, Optional, Union
 
 from packaging.version import Version
 
@@ -13,12 +13,6 @@ from ansible_compat.constants import ANSIBLE_MIN_VERSION
 from ansible_compat.errors import InvalidPrerequisiteError, MissingAnsibleError
 from ansible_compat.ports import cache
 
-if TYPE_CHECKING:
-    # https://github.com/PyCQA/pylint/issues/3285
-    _UserDict = UserDict[str, object]  # pylint: disable=unsubscriptable-object
-else:
-    _UserDict = UserDict
-
 
 # do not use lru_cache here, as environment can change between calls
 def ansible_collections_path() -> str:
@@ -32,13 +26,14 @@ def parse_ansible_version(stdout: str) -> Version:
 
     # ansible-core 2.11+: 'ansible [core 2.11.3]'
     match = re.search(
-        r"^ansible \[(?:core|base) (?P<version>[^\]]+)\]", stdout, re.MULTILINE
+        r"^ansible \[(?:core|base) (?P<version>[^\]]+)\]",
+        stdout,
+        re.MULTILINE,
     )
     if match:
         return Version(match.group("version"))
-    raise InvalidPrerequisiteError(
-        f"Unable to parse ansible cli version: {stdout}\nKeep in mind that only {ANSIBLE_MIN_VERSION } or newer are supported."
-    )
+    msg = f"Unable to parse ansible cli version: {stdout}\nKeep in mind that only {ANSIBLE_MIN_VERSION } or newer are supported."
+    raise InvalidPrerequisiteError(msg)
 
 
 @cache
@@ -53,21 +48,18 @@ def ansible_version(version: str = "") -> Version:
         return Version(version)
 
     proc = subprocess.run(
-        ["ansible", "--version"],
-        universal_newlines=True,
+        ["ansible", "--version"],  # noqa: S603
+        text=True,
         check=False,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
     )
     if proc.returncode != 0:
-        raise MissingAnsibleError(
-            "Unable to find a working copy of ansible executable.", proc=proc
-        )
+        raise MissingAnsibleError(proc=proc)
 
     return parse_ansible_version(proc.stdout)
 
 
-class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
+class AnsibleConfig(UserDict[str, object]):  # pylint: disable=too-many-ancestors
     """Interface to query Ansible configuration.
 
     This should allow user to access everything provided by `ansible-config dump` without having to parse the data himself.
@@ -82,7 +74,7 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     agnostic_become_prompt: bool = True
     allow_world_readable_tmpfiles: bool = False
     ansible_connection_path: Optional[str] = None
-    ansible_cow_acceptlist: List[str]
+    ansible_cow_acceptlist: list[str]
     ansible_cow_path: Optional[str] = None
     ansible_cow_selection: str = "default"
     ansible_force_color: bool = False
@@ -91,7 +83,7 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     ansible_pipelining: bool = False
     any_errors_fatal: bool = False
     become_allow_same_user: bool = False
-    become_plugin_path: List[str] = [
+    become_plugin_path: list[str] = [
         "~/.ansible/plugins/become",
         "/usr/share/ansible/plugins/become",
     ]
@@ -99,12 +91,14 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     cache_plugin_connection: Optional[str] = None
     cache_plugin_prefix: str = "ansible_facts"
     cache_plugin_timeout: int = 86400
-    callable_accept_list: List[str] = []
-    callbacks_enabled: List[str] = []
+    callable_accept_list: list[str] = []
+    callbacks_enabled: list[str] = []
     collections_on_ansible_version_mismatch: Union[
-        Literal["warning"], Literal["warning"], Literal["ignore"]
+        Literal["warning"],
+        Literal["warning"],
+        Literal["ignore"],
     ] = "warning"
-    collections_paths: List[str] = [
+    collections_paths: list[str] = [
         "~/.ansible/collections",
         "/usr/share/ansible/collections",
     ]
@@ -125,11 +119,11 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     color_warn: str = "bright purple"
     command_warnings: bool = False
     conditional_bare_vars: bool = False
-    connection_facts_modules: Dict[str, str]
+    connection_facts_modules: dict[str, str]
     controller_python_warning: bool = True
     coverage_remote_output: Optional[str]
-    coverage_remote_paths: List[str]
-    default_action_plugin_path: List[str] = [
+    coverage_remote_paths: list[str]
+    default_action_plugin_path: list[str] = [
         "~/.ansible/plugins/action",
         "/usr/share/ansible/plugins/action",
     ]
@@ -142,57 +136,59 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     default_become_flags: str
     default_become_method: str = "sudo"
     default_become_user: str = "root"
-    default_cache_plugin_path: List[str] = [
+    default_cache_plugin_path: list[str] = [
         "~/.ansible/plugins/cache",
         "/usr/share/ansible/plugins/cache",
     ]
-    default_callback_plugin_path: List[str] = [
+    default_callback_plugin_path: list[str] = [
         "~/.ansible/plugins/callback",
         "/usr/share/ansible/plugins/callback",
     ]
-    default_cliconf_plugin_path: List[str] = [
+    default_cliconf_plugin_path: list[str] = [
         "~/.ansible/plugins/cliconf",
         "/usr/share/ansible/plugins/cliconf",
     ]
-    default_connection_plugin_path: List[str] = [
+    default_connection_plugin_path: list[str] = [
         "~/.ansible/plugins/connection",
         "/usr/share/ansible/plugins/connection",
     ]
     default_debug: bool = False
     default_executable: str = "/bin/sh"
     default_fact_path: Optional[str] = None
-    default_filter_plugin_path: List[str] = [
+    default_filter_plugin_path: list[str] = [
         "~/.ansible/plugins/filter",
         "/usr/share/ansible/plugins/filter",
     ]
     default_force_handlers: bool = False
     default_forks: int = 5
     default_gathering: Union[
-        Literal["smart"], Literal["explicit"], Literal["implicit"]
+        Literal["smart"],
+        Literal["explicit"],
+        Literal["implicit"],
     ] = "smart"
-    default_gather_subset: List[str] = ["all"]
+    default_gather_subset: list[str] = ["all"]
     default_gather_timeout: int = 10
     default_handler_includes_static: bool = False
     default_hash_behaviour: str = "replace"
-    default_host_list: List[str] = ["/etc/ansible/hosts"]
-    default_httpapi_plugin_path: List[str] = [
+    default_host_list: list[str] = ["/etc/ansible/hosts"]
+    default_httpapi_plugin_path: list[str] = [
         "~/.ansible/plugins/httpapi",
         "/usr/share/ansible/plugins/httpapi",
     ]
     default_internal_poll_interval: float = 0.001
-    default_inventory_plugin_path: List[str] = [
+    default_inventory_plugin_path: list[str] = [
         "~/.ansible/plugins/inventory",
         "/usr/share/ansible/plugins/inventory",
     ]
-    default_jinja2_extensions: List[str] = []
+    default_jinja2_extensions: list[str] = []
     default_jinja2_native: bool = False
     default_keep_remote_files: bool = False
     default_libvirt_lxc_noseclabel: bool = False
     default_load_callback_plugins: bool = False
     default_local_tmp: str = "~/.ansible/tmp"
-    default_log_filter: List[str] = []
+    default_log_filter: list[str] = []
     default_log_path: Optional[str] = None
-    default_lookup_lugin_path: List[str] = [
+    default_lookup_lugin_path: list[str] = [
         "~/.ansible/plugins/lookup",
         "/usr/share/ansible/plugins/lookup",
     ]
@@ -200,15 +196,15 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     default_module_args: str
     default_module_compression: str = "ZIP_DEFLATED"
     default_module_name: str = "command"
-    default_module_path: List[str] = [
+    default_module_path: list[str] = [
         "~/.ansible/plugins/modules",
         "/usr/share/ansible/plugins/modules",
     ]
-    default_module_utils_path: List[str] = [
+    default_module_utils_path: list[str] = [
         "~/.ansible/plugins/module_utils",
         "/usr/share/ansible/plugins/module_utils",
     ]
-    default_netconf_plugin_path: List[str] = [
+    default_netconf_plugin_path: list[str] = [
         "~/.ansible/plugins/netconf",
         "/usr/share/ansible/plugins/netconf",
     ]
@@ -220,12 +216,12 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     default_private_role_vars: bool = False
     default_remote_port: Optional[str] = None
     default_remote_user: Optional[str] = None
-    default_roles_path: List[str] = [
+    default_roles_path: list[str] = [
         "~/.ansible/roles",
         "/usr/share/ansible/roles",
         "/etc/ansible/roles",
     ]
-    default_selinux_special_fs: List[str] = [
+    default_selinux_special_fs: list[str] = [
         "fuse",
         "nfs",
         "vboxsf",
@@ -235,31 +231,31 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     ]
     default_stdout_callback: str = "default"
     default_strategy: str = "linear"
-    default_strategy_plugin_path: List[str] = [
+    default_strategy_plugin_path: list[str] = [
         "~/.ansible/plugins/strategy",
         "/usr/share/ansible/plugins/strategy",
     ]
     default_su: bool = False
     default_syslog_facility: str = "LOG_USER"
     default_task_includes_static: bool = False
-    default_terminal_plugin_path: List[str] = [
+    default_terminal_plugin_path: list[str] = [
         "~/.ansible/plugins/terminal",
         "/usr/share/ansible/plugins/terminal",
     ]
-    default_test_plugin_path: List[str] = [
+    default_test_plugin_path: list[str] = [
         "~/.ansible/plugins/test",
         "/usr/share/ansible/plugins/test",
     ]
     default_timeout: int = 10
     default_transport: str = "smart"
     default_undefined_var_behavior: bool = True
-    default_vars_plugin_path: List[str] = [
+    default_vars_plugin_path: list[str] = [
         "~/.ansible/plugins/vars",
         "/usr/share/ansible/plugins/vars",
     ]
     default_vault_encrypt_identity: Optional[str] = None
     default_vault_identity: str = "default"
-    default_vault_identity_list: List[str] = []
+    default_vault_identity_list: list[str] = []
     default_vault_id_match: bool = False
     default_vault_password_file: Optional[str] = None
     default_verbosity: int = 0
@@ -270,32 +266,36 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     display_args_to_stdout: bool = False
     display_skipped_hosts: bool = True
     docsite_root_url: str = "https://docs.ansible.com/ansible/"
-    doc_fragment_plugin_path: List[str] = [
+    doc_fragment_plugin_path: list[str] = [
         "~/.ansible/plugins/doc_fragments",
         "/usr/share/ansible/plugins/doc_fragments",
     ]
     duplicate_yaml_dict_key: Union[
-        Literal["warn"], Literal["error"], Literal["ignore"]
+        Literal["warn"],
+        Literal["error"],
+        Literal["ignore"],
     ] = "warn"
     enable_task_debugger: bool = False
     error_on_missing_handler: bool = True
-    facts_modules: List[str] = ["smart"]
+    facts_modules: list[str] = ["smart"]
     galaxy_cache_dir: str = "~/.ansible/galaxy_cache"
     galaxy_display_progress: Optional[str] = None
     galaxy_ignore_certs: bool = False
     galaxy_role_skeleton: Optional[str] = None
-    galaxy_role_skeleton_ignore: List[str] = ["^.git$", "^.*/.git_keep$"]
+    galaxy_role_skeleton_ignore: list[str] = ["^.git$", "^.*/.git_keep$"]
     galaxy_server: str = "https://galaxy.ansible.com"
     galaxy_server_list: Optional[str] = None
     galaxy_token_path: str = "~/.ansible/galaxy_token"
     host_key_checking: bool = True
     host_pattern_mismatch: Union[
-        Literal["warning"], Literal["error"], Literal["ignore"]
+        Literal["warning"],
+        Literal["error"],
+        Literal["ignore"],
     ] = "warning"
     inject_facts_as_vars: bool = True
     interpreter_python: str = "auto_legacy"
-    interpreter_python_distro_map: Dict[str, str]
-    interpreter_python_fallback: List[str]
+    interpreter_python_distro_map: dict[str, str]
+    interpreter_python_fallback: list[str]
     invalid_task_attribute_failed: bool = True
     inventory_any_unparsed_is_failed: bool = False
     inventory_cache_enabled: bool = False
@@ -303,7 +303,7 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     inventory_cache_plugin_connection: Optional[str] = None
     inventory_cache_plugin_prefix: str = "ansible_facts"
     inventory_cache_timeout: int = 3600
-    inventory_enabled: List[str] = [
+    inventory_enabled: list[str] = [
         "host_list",
         "script",
         "auto",
@@ -313,13 +313,13 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     ]
     inventory_export: bool = False
     inventory_ignore_exts: str
-    inventory_ignore_patterns: List[str] = []
+    inventory_ignore_patterns: list[str] = []
     inventory_unparsed_is_failed: bool = False
     localhost_warning: bool = True
     max_file_size_for_diff: int = 104448
     module_ignore_exts: str
     netconf_ssh_config: Optional[str] = None
-    network_group_modules: List[str] = [
+    network_group_modules: list[str] = [
         "eos",
         "nxos",
         "ios",
@@ -359,9 +359,11 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     run_vars_plugins: str = "demand"
     show_custom_stats: bool = False
     string_conversion_action: Union[
-        Literal["warn"], Literal["error"], Literal["ignore"]
+        Literal["warn"],
+        Literal["error"],
+        Literal["ignore"],
     ] = "warn"
-    string_type_filters: List[str] = [
+    string_type_filters: list[str] = [
         "string",
         "to_json",
         "to_nice_json",
@@ -371,16 +373,19 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
         "json",
     ]
     system_warnings: bool = True
-    tags_run: List[str] = []
-    tags_skip: List[str] = []
+    tags_run: list[str] = []
+    tags_skip: list[str] = []
     task_debugger_ignore_errors: bool = True
     task_timeout: int = 0
     transform_invalid_group_chars: Union[
-        Literal["always"], Literal["never"], Literal["ignore"], Literal["silently"]
+        Literal["always"],
+        Literal["never"],
+        Literal["ignore"],
+        Literal["silently"],
     ] = "never"
     use_persistent_connections: bool = False
-    variable_plugins_enabled: List[str] = ["host_group_vars"]
-    variable_precedence: List[str] = [
+    variable_plugins_enabled: list[str] = ["host_group_vars"]
+    variable_precedence: list[str] = [
         "all_inventory",
         "groups_inventory",
         "all_plugins_inventory",
@@ -392,12 +397,12 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
     win_async_startup_timeout: int = 5
     worker_shutdown_poll_count: int = 0
     worker_shutdown_poll_delay: float = 0.1
-    yaml_filename_extensions: List[str] = [".yml", ".yaml", ".json"]
+    yaml_filename_extensions: list[str] = [".yml", ".yaml", ".json"]
 
     def __init__(
         self,
         config_dump: Optional[str] = None,
-        data: Optional[Dict[str, object]] = None,
+        data: Optional[dict[str, object]] = None,
     ) -> None:
         """Load config dictionary."""
         super().__init__()
@@ -411,11 +416,15 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
             # Avoid possible ANSI garbage
             env["ANSIBLE_FORCE_COLOR"] = "0"
             config_dump = subprocess.check_output(
-                ["ansible-config", "dump"], universal_newlines=True, env=env
+                ["ansible-config", "dump"],  # noqa: S603
+                universal_newlines=True,
+                env=env,
             )
 
         for match in re.finditer(
-            r"^(?P<key>[A-Za-z0-9_]+).* = (?P<value>.*)$", config_dump, re.MULTILINE
+            r"^(?P<key>[A-Za-z0-9_]+).* = (?P<value>.*)$",
+            config_dump,
+            re.MULTILINE,
         ):
             key = match.groupdict()["key"]
             value = match.groupdict()["value"]
@@ -431,7 +440,7 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
             return _dict[attr_name]
 
         data = super().__getattribute__("data")
-        if attr_name == "data":
+        if attr_name == "data":  # pragma: no cover
             return data
 
         name = attr_name.upper()
@@ -454,13 +463,6 @@ class AnsibleConfig(_UserDict):  # pylint: disable=too-many-ancestors
         """Allow users to run deeepcopy on Config."""
         return AnsibleConfig(data=self.data)
 
-    def _dump_config_attrs(self) -> None:  # pragma: no cover
-        """Dump config attributes using pytest typed format."""
-        for item in sorted(self.data):
-            name = item.lower()
-            kind = self.data[item].__class__.__name__
-            print(f"{name}: {kind}")
-
 
 __all__ = [
     "ansible_collections_path",
